package com.aucma.dms.service;

import com.aucma.dms.domain.DmsPlanLubeDetail;

import java.util.List;

/**
 * 润滑计划明细Service接口
 *
 * @author xins
 * @date 2024-03-21
 */
public interface IDmsPlanLubeDetailService
{
    /**
     * 查询润滑计划明细
     *
     * @param planLubeDetailId 润滑计划明细主键
     * @return 润滑计划明细
     */
    public DmsPlanLubeDetail selectDmsPlanLubeDetailByPlanLubeDetailId(Long planLubeDetailId);

    /**
     * 查询润滑计划明细列表
     *
     * @param dmsPlanLubeDetail 润滑计划明细
     * @return 润滑计划明细集合
     */
    public List<DmsPlanLubeDetail> selectDmsPlanLubeDetailList(DmsPlanLubeDetail dmsPlanLubeDetail);

    /**
     * 新增润滑计划明细
     *
     * @param dmsPlanLubeDetail 润滑计划明细
     * @return 结果
     */
    public int insertDmsPlanLubeDetail(DmsPlanLubeDetail dmsPlanLubeDetail);

    /**
     * 修改润滑计划明细
     *
     * @param dmsPlanLubeDetail 润滑计划明细
     * @return 结果
     */
    public int updateDmsPlanLubeDetail(DmsPlanLubeDetail dmsPlanLubeDetail);

    /**
     * 批量删除润滑计划明细
     *
     * @param planLubeDetailIds 需要删除的润滑计划明细主键集合
     * @return 结果
     */
    public int deleteDmsPlanLubeDetailByPlanLubeDetailIds(Long[] planLubeDetailIds);

    /**
     * 删除润滑计划明细信息
     *
     * @param planLubeDetailId 润滑计划明细主键
     * @return 结果
     */
    public int deleteDmsPlanLubeDetailByPlanLubeDetailId(Long planLubeDetailId);

    List<DmsPlanLubeDetail> selectPlanLubeDetailByPlanLubeId(Long planLubeId);
}
